@@ -1,7 +1,8 @@
 from canvas_sdk.commands.commands.questionnaire import QuestionnaireCommand
+from canvas_sdk.commands.commands.questionnaire.toggle_questions import ToggleQuestionsMixin
 
 
-class PhysicalExamCommand(QuestionnaireCommand):
+class PhysicalExamCommand(ToggleQuestionsMixin, QuestionnaireCommand):
     """A class for managing physical exam command."""
 
     class Meta:
