@@ -74,12 +74,16 @@ class PrescribeCommand(_SendableCommandMixin, _BaseCommand):
         default=None, json_schema_extra={"commands_api_name": "compound_medication_data"}
     )
 
+    def _has_fdb_code(self) -> bool:
+        """Check if fdb_code is provided and non-empty."""
+        return self.fdb_code is not None and self.fdb_code.strip() != ""
+
     def _get_error_details(self, method: str) -> list[InitErrorDetails]:
         """Add compound medication validation to the base validation."""
         errors = super()._get_error_details(method)
 
         # Validate that exactly one medication type is provided
-        has_fdb_code = self.fdb_code is not None and self.fdb_code.strip() != ""
+        has_fdb_code = self._has_fdb_code()
         has_compound_medication_id = (
             self.compound_medication_id is not None and self.compound_medication_id.strip() != ""
         )
@@ -156,10 +160,8 @@ class PrescribeCommand(_SendableCommandMixin, _BaseCommand):
                 str(Decimal(self.quantity_to_dispense)) if self.quantity_to_dispense else None
             )
 
-        values["compound_medication_values"] = {}
-
         if self.is_dirty("compound_medication_id") and self.compound_medication_id:
-            values["compound_medication_values"]["id"] = values.pop("compound_medication_id")
+            values["compound_medication_values"] = {"id": values.pop("compound_medication_id")}
 
         # Handle compound medication data
         elif (
@@ -170,9 +172,6 @@ class PrescribeCommand(_SendableCommandMixin, _BaseCommand):
             if isinstance(compound_data, CompoundMedicationData):
                 values["compound_medication_values"] = compound_data.to_dict()
 
-        if values.get("fdb_code") is not None and values.get("compound_medication_values") == {}:
-            del values["compound_medication_values"]
-
         return values
 
     def originate(self, line_number: int = -1) -> Effect:
