@@ -1,9 +1,11 @@
 from typing import Literal
+from uuid import UUID
 
 from pydantic_core import InitErrorDetails
 
 from canvas_sdk.commands.base import _BaseCommand
 from canvas_sdk.commands.constants import Coding
+from canvas_sdk.v1.data import ReasonForVisitSettingCoding
 
 
 class ReasonForVisitCommand(_BaseCommand):
@@ -13,8 +15,7 @@ class ReasonForVisitCommand(_BaseCommand):
         key = "reasonForVisit"
 
     structured: bool = False
-    # how do we make sure that coding is a valid rfv coding from their home-app?
-    coding: Coding | None = None
+    coding: Coding | UUID | str | None = None
     comment: str | None = None
 
     def _get_error_details(
@@ -24,9 +25,19 @@ class ReasonForVisitCommand(_BaseCommand):
         if self.structured and not self.coding:
             errors.append(
                 self._create_error_detail(
-                    "value", f"Structured RFV should have a coding.", self.coding
+                    "value", "Structured RFV should have a coding.", self.coding
                 )
             )
+
+        if self.coding:
+            if isinstance(self.coding, str | UUID):
+                query = {"id": self.coding}
+                error_message = f"ReasonForVisitSettingCoding with id {self.coding} does not exist."
+            else:
+                query = {"code": self.coding["code"], "system": self.coding["system"]}
+                error_message = f"ReasonForVisitSettingCoding with code {self.coding['code']} and system {self.coding['system']} does not exist."
+            if not ReasonForVisitSettingCoding.objects.filter(**query).exists():
+                errors.append(self._create_error_detail("value", error_message, self.coding))
         return errors
 
     @classmethod
@@ -37,7 +48,5 @@ class ReasonForVisitCommand(_BaseCommand):
         command_schema.pop("structured")
         return command_schema
 
-    @property
-    def values(self) -> dict:
-        """The ReasonForVisit command's field values."""
-        return {"structured": self.structured, "coding": self.coding, "comment": self.comment}
+
+__exports__ = ("ReasonForVisitCommand",)
