@@ -1,7 +1,8 @@
 from datetime import date
-from enum import Enum, StrEnum
+from enum import StrEnum
+from typing import NotRequired
 
-from typing_extensions import NotRequired, TypedDict
+from typing_extensions import TypedDict
 
 from canvas_sdk.commands.base import _BaseCommand as BaseCommand
 
@@ -27,10 +28,6 @@ class TaskCommand(BaseCommand):
 
     class Meta:
         key = "task"
-        commit_required_fields = (
-            "title",
-            "assign_to",
-        )
 
     title: str = ""
     assign_to: TaskAssigner | None = None
@@ -39,14 +36,9 @@ class TaskCommand(BaseCommand):
     labels: list[str] | None = None
     linked_items_urns: list[str] | None = None
 
-    @property
-    def values(self) -> dict:
-        """The Task command's field values."""
-        return {
-            "title": self.title,
-            "assign_to": self.assign_to,
-            "due_date": self.due_date.isoformat() if self.due_date else None,
-            "comment": self.comment,
-            "labels": self.labels,
-            "linked_items_urns": self.linked_items_urns,
-        }
+
+__exports__ = (
+    "AssigneeType",
+    "TaskAssigner",
+    "TaskCommand",
+)
