@@ -159,11 +159,35 @@ class AppointmentABC(NoteOrAppointmentABC, ABC):
     duration_minutes: int | None = None
     status: AppointmentProgressStatus | None = None
     external_identifiers: list[AppointmentIdentifier] | None = None
+    parent_appointment_id: str | UUID | None = None
 
     def _get_error_details(self, method: Any) -> list[InitErrorDetails]:
         """Validates the appointment instance and returns a list of error details if validation fails."""
         errors = super()._get_error_details(method)
 
+        if method != "create" and self.parent_appointment_id:
+            errors.append(
+                self._create_error_detail(
+                    "value",
+                    "parent_appointment_id can only be set when creating an appointment.",
+                    self.parent_appointment_id,
+                )
+            )
+
+        # parent_appointment_id needs to be a different appointment
+        if (
+            self.parent_appointment_id
+            and self.instance_id
+            and self.parent_appointment_id == self.instance_id
+        ):
+            errors.append(
+                self._create_error_detail(
+                    "value",
+                    "parent_appointment_id cannot be the same as instance_id",
+                    self.parent_appointment_id,
+                )
+            )
+
         if method == "create":
             # Additional required fields for appointment creation
             if not self.start_time:
@@ -215,5 +239,22 @@ class AppointmentABC(NoteOrAppointmentABC, ABC):
 
         return values
 
+    def reschedule(self) -> Effect:
+        """Send a RESCHEDULE effect for the appointment."""
+        self._validate_before_effect("update")
+
+        # Check if any fields were actually modified
+        if self._dirty_keys == {"instance_id"}:
+            raise ValueError("No fields have been modified. Nothing to update.")
+
+        return Effect(
+            type=f"RESCHEDULE_{self.Meta.effect_type}",
+            payload=json.dumps(
+                {
+                    "data": self.values,
+                }
+            ),
+        )
+
 
 __exports__ = ("AppointmentIdentifier", "NoteOrAppointmentABC", "AppointmentABC")
