@@ -3,6 +3,7 @@ from canvas_sdk.effects.patient.base import (
     PatientAddress,
     PatientContactPoint,
     PatientExternalIdentifier,
+    PatientMetadata,
     PatientPreferredPharmacy,
 )
 from canvas_sdk.effects.patient.create_patient_external_identifier import (
@@ -18,6 +19,7 @@ __all__ = __exports__ = (
     "PatientContactPoint",
     "PatientExternalIdentifier",
     "PatientPreferredPharmacy",
+    "PatientMetadata",
     "CreatePatientExternalIdentifier",
     "CreatePatientPreferredPharmacies",
 )
