@@ -1,11 +1,25 @@
+from functools import cache, lru_cache
 from pathlib import Path
 from typing import Any
 
-from django.template import Context, Template
+from django.template.backends.django import get_installed_libraries
+from django.template.engine import Engine
 
 from canvas_sdk.utils.plugins import plugin_context
 
 
+@cache
+def _installed_template_libraries() -> dict[str, str]:
+    """Cache Django's template tag libraries lookup."""
+    return get_installed_libraries()
+
+
+@lru_cache(maxsize=5)
+def _engine_for_plugin(plugin_dir: str) -> Engine:
+    """Create a Django template engine for the given plugin directory."""
+    return Engine(dirs=[plugin_dir], libraries=_installed_template_libraries())
+
+
 @plugin_context
 def render_to_string(
     template_name: str,
@@ -36,9 +50,8 @@ def render_to_string(
     elif not template_path.exists():
         raise FileNotFoundError(f"Template {template_name} not found.")
 
-    template = Template(template_path.read_text())
-
-    return template.render(Context(context))
+    engine = _engine_for_plugin(plugin_dir)
+    return engine.render_to_string(str(template_path), context=context)
 
 
 __exports__ = ("render_to_string",)
