@@ -1,6 +1,6 @@
 from django.db import models
 
-from canvas_sdk.v1.data.base import IdentifiableModel
+from canvas_sdk.v1.data.base import AuditedModel, IdentifiableModel
 
 
 class AssessmentStatus(models.TextChoices):
@@ -11,22 +11,12 @@ class AssessmentStatus(models.TextChoices):
     STATUS_DETERIORATING = "deteriorated", "Deteriorated"
 
 
-class Assessment(IdentifiableModel):
+class Assessment(AuditedModel, IdentifiableModel):
     """Assessment."""
 
     class Meta:
         db_table = "canvas_sdk_data_api_assessment_001"
 
-    created = models.DateTimeField(auto_now_add=True)
-    modified = models.DateTimeField(auto_now=True)
-    originator = models.ForeignKey("v1.CanvasUser", on_delete=models.DO_NOTHING, related_name="+")
-    committer = models.ForeignKey(
-        "v1.CanvasUser", on_delete=models.DO_NOTHING, null=True, related_name="+"
-    )
-    deleted = models.BooleanField()
-    entered_in_error = models.ForeignKey(
-        "v1.CanvasUser", on_delete=models.DO_NOTHING, null=True, related_name="+"
-    )
     patient = models.ForeignKey(
         "v1.Patient",
         on_delete=models.DO_NOTHING,
