@@ -1,6 +1,7 @@
 from django.db import models
 
-from canvas_sdk.v1.data.base import IdentifiableModel, Model
+from canvas_sdk.v1.data.base import IdentifiableModel, TimestampedModel
+from canvas_sdk.v1.data.coding import Coding
 
 
 class CareTeamMembershipStatus(models.TextChoices):
@@ -13,31 +14,24 @@ class CareTeamMembershipStatus(models.TextChoices):
     ENTERED_IN_ERROR = "entered-in-error", "Entered in Error"
 
 
-class CareTeamRole(Model):
+class CareTeamRole(Coding):
     """CareTeamRole."""
 
     class Meta:
         db_table = "canvas_sdk_data_api_careteamrole_001"
 
-    system = models.CharField(max_length=255)
-    version = models.CharField(max_length=255)
-    code = models.CharField(max_length=255)
-    display = models.CharField(max_length=1000)
-    user_selected = models.BooleanField()
     active = models.BooleanField()
 
     def __str__(self) -> str:
         return self.display
 
 
-class CareTeamMembership(IdentifiableModel):
+class CareTeamMembership(TimestampedModel, IdentifiableModel):
     """CareTeamMembership."""
 
     class Meta:
         db_table = "canvas_sdk_data_api_careteammembership_001"
 
-    created = models.DateTimeField(auto_now_add=True)
-    modified = models.DateTimeField(auto_now=True)
     patient = models.ForeignKey(
         "v1.Patient", on_delete=models.DO_NOTHING, related_name="care_team_memberships", null=True
     )
