@@ -3,7 +3,7 @@ from typing import TYPE_CHECKING, Self
 
 from django.db import models
 
-from canvas_sdk.v1.data.base import IdentifiableModel, Model
+from canvas_sdk.v1.data.base import IdentifiableModel, TimestampedModel
 from canvas_sdk.v1.data.common import PersonSex
 from canvas_sdk.v1.data.coverage import CoverageRelationshipCode, CoverageType
 from canvas_sdk.v1.data.fields import ChoiceArrayField
@@ -21,7 +21,7 @@ class InstallmentPlanStatus(models.TextChoices):
     CANCELLED = "cancelled", "Cancelled"
 
 
-class InstallmentPlan(Model):
+class InstallmentPlan(TimestampedModel):
     """InstallmentPlan."""
 
     class Meta:
@@ -35,9 +35,6 @@ class InstallmentPlan(Model):
     status = models.CharField(choices=InstallmentPlanStatus.choices, max_length=10)
     expected_payoff_date = models.DateField()
 
-    created = models.DateTimeField(auto_now_add=True)
-    modified = models.DateTimeField(auto_now=True)
-
 
 class ClaimQueueColumns(models.TextChoices):
     """ClaimQueueColumns."""
@@ -73,7 +70,7 @@ class ClaimQueues(models.IntegerChoices):
     TRASH = 10, "Trash"
 
 
-class ClaimQueue(Model):
+class ClaimQueue(TimestampedModel):
     """ClaimQueue."""
 
     class Meta:
@@ -83,14 +80,11 @@ class ClaimQueue(Model):
     name = models.CharField(max_length=100)
     display_name = models.CharField(max_length=100)
     description = models.CharField(max_length=500)
-    show_in_revenue = models.BooleanField()
+    show_in_revenue = models.BooleanField(default=True)
     visible_columns = ChoiceArrayField(
         models.CharField(choices=ClaimQueueColumns.choices, max_length=64)
     )
 
-    created = models.DateTimeField(auto_now_add=True)
-    modified = models.DateTimeField(auto_now=True)
-
 
 class ClaimPayerOrder(models.TextChoices):
     """ClaimPayerOrder."""
@@ -124,7 +118,7 @@ class ClaimCoverageQuerySet(models.QuerySet):
         return self.filter(active=True)
 
 
-class ClaimCoverage(Model):
+class ClaimCoverage(TimestampedModel):
     """A model that represents the link between a claim and a specific insurance coverage."""
 
     class Meta:
@@ -180,11 +174,8 @@ class ClaimCoverage(Model):
     resubmission_code = models.CharField(max_length=1)
     payer_icn = models.CharField(max_length=250)
 
-    created = models.DateTimeField(auto_now_add=True)
-    modified = models.DateTimeField(auto_now=True)
 
-
-class ClaimPatient(Model):
+class ClaimPatient(TimestampedModel):
     """ClaimPatient."""
 
     class Meta:
@@ -206,9 +197,6 @@ class ClaimPatient(Model):
     zip = models.CharField(max_length=255)
     country = models.CharField(max_length=50)
 
-    created = models.DateTimeField(auto_now_add=True)
-    modified = models.DateTimeField(auto_now=True)
-
 
 class ClaimQueryset(models.QuerySet):
     """ClaimQueryset."""
@@ -218,7 +206,7 @@ class ClaimQueryset(models.QuerySet):
         return self.exclude(current_queue__queue_sort_ordering=ClaimQueues.TRASH)
 
 
-class Claim(IdentifiableModel):
+class Claim(TimestampedModel, IdentifiableModel):
     """Claim."""
 
     class Meta:
@@ -236,25 +224,23 @@ class Claim(IdentifiableModel):
         ClaimCoverage, related_name="claims", on_delete=models.SET_NULL, null=True
     )
 
-    accept_assign = models.BooleanField()
-    auto_accident = models.BooleanField()
+    accept_assign = models.BooleanField(default=True)
+    auto_accident = models.BooleanField(default=False)
     auto_accident_state = models.CharField(max_length=2)
-    employment_related = models.BooleanField()
-    other_accident = models.BooleanField()
+    employment_related = models.BooleanField(default=False)
+    other_accident = models.BooleanField(default=False)
     accident_code = models.CharField(max_length=10)
-    illness_date = models.DateField()
+    illness_date = models.DateField(blank=True, null=True)
     remote_batch_id = models.CharField(max_length=100)
     remote_file_id = models.CharField(max_length=100)
     prior_auth = models.CharField(max_length=100)
 
     narrative = models.CharField(max_length=2500)
     account_number = models.CharField(max_length=255)
-    snoozed_until = models.DateField()
+    snoozed_until = models.DateField(null=True)
 
-    patient_balance = models.DecimalField(max_digits=8, decimal_places=2)
-    aggregate_coverage_balance = models.DecimalField(max_digits=8, decimal_places=2)
-    created = models.DateTimeField(auto_now_add=True)
-    modified = models.DateTimeField(auto_now=True)
+    patient_balance = models.DecimalField(max_digits=8, decimal_places=2, default=0.00)
+    aggregate_coverage_balance = models.DecimalField(max_digits=8, decimal_places=2, default=0.00)
 
     @property
     def total_charges(self) -> Decimal:
