@@ -1,30 +1,18 @@
 from django.db import models
 
-from canvas_sdk.v1.data.base import IdentifiableModel
+from canvas_sdk.v1.data.base import AuditedModel, IdentifiableModel
 
 
-class Device(IdentifiableModel):
+class Device(AuditedModel, IdentifiableModel):
     """Device."""
 
     class Meta:
         db_table = "canvas_sdk_data_api_device_001"
 
-    created = models.DateTimeField(auto_now_add=True)
-    modified = models.DateTimeField(auto_now=True)
-    originator = models.ForeignKey(
-        "v1.CanvasUser", on_delete=models.DO_NOTHING, null=True, related_name="+"
-    )
-    committer = models.ForeignKey(
-        "v1.CanvasUser", on_delete=models.DO_NOTHING, null=True, related_name="+"
-    )
-    entered_in_error = models.ForeignKey(
-        "v1.CanvasUser", on_delete=models.DO_NOTHING, null=True, related_name="+"
-    )
     patient = models.ForeignKey(
         "v1.Patient", on_delete=models.DO_NOTHING, related_name="devices", null=True
     )
     note_id = models.BigIntegerField()
-    deleted = models.BooleanField()
     labeled_contains_NRL = models.BooleanField()
     assigning_authority = models.CharField(max_length=255)
     scoping_entity = models.CharField(max_length=255)
