@@ -7,7 +7,7 @@ from django.contrib.postgres.fields import ArrayField
 from django.db import models
 from django.db.models import TextChoices
 
-from canvas_sdk.v1.data.base import IdentifiableModel, Model
+from canvas_sdk.v1.data.base import IdentifiableModel, TimestampedModel
 from canvas_sdk.v1.data.common import (
     AddressState,
     AddressType,
@@ -39,7 +39,7 @@ class PatientSettingConstants:
     PREFERRED_SCHEDULING_TIMEZONE = "preferredSchedulingTimezone"
 
 
-class Patient(Model):
+class Patient(TimestampedModel):
     """A class representing a patient."""
 
     class Meta:
@@ -72,6 +72,9 @@ class Patient(Model):
     biological_race_codes = ArrayField(
         models.CharField(max_length=100, default="", blank=True), default=list, blank=True
     )
+    cultural_ethnicity_codes = ArrayField(
+        models.CharField(max_length=100, default="", blank=True), default=list, blank=True
+    )
     last_known_timezone = models.CharField(max_length=32, null=True, blank=True)
     mrn = models.CharField(max_length=9, unique=True, default=generate_mrn)
     active = models.BooleanField(default=True)
@@ -105,9 +108,6 @@ class Patient(Model):
     )
     user = models.ForeignKey("v1.CanvasUser", on_delete=models.DO_NOTHING, null=True)
 
-    created = models.DateTimeField(auto_now_add=True)
-    modified = models.DateTimeField(auto_now=True)
-
     @classmethod
     def find(cls, id: str) -> Patient:
         """Find a patient by id."""
@@ -240,14 +240,12 @@ class PatientAddress(IdentifiableModel):
         return f"id={self.id}"
 
 
-class PatientExternalIdentifier(IdentifiableModel):
+class PatientExternalIdentifier(TimestampedModel, IdentifiableModel):
     """A class representing a patient external identifier."""
 
     class Meta:
         db_table = "canvas_sdk_data_api_patientexternalidentifier_001"
 
-    created = models.DateTimeField(auto_now_add=True)
-    modified = models.DateTimeField(auto_now=True)
     patient = models.ForeignKey(
         "v1.Patient",
         related_name="external_identifiers",
@@ -265,14 +263,12 @@ class PatientExternalIdentifier(IdentifiableModel):
         return f"id={self.id}"
 
 
-class PatientSetting(Model):
+class PatientSetting(TimestampedModel):
     """PatientSetting."""
 
     class Meta:
         db_table = "canvas_sdk_data_api_patientsetting_001"
 
-    created = models.DateTimeField(auto_now_add=True)
-    modified = models.DateTimeField(auto_now=True)
     patient = models.ForeignKey(
         "v1.Patient", on_delete=models.DO_NOTHING, related_name="settings", null=True
     )
@@ -287,10 +283,10 @@ class PatientMetadata(IdentifiableModel):
         db_table = "canvas_sdk_data_api_patientmetadata_001"
 
     patient = models.ForeignKey(
-        "v1.Patient", on_delete=models.DO_NOTHING, related_name="metadata", null=True
+        "v1.Patient", on_delete=models.CASCADE, related_name="metadata", null=True
     )
-    key = models.CharField(max_length=255)
-    value = models.CharField(max_length=255)
+    key = models.CharField(max_length=32)
+    value = models.CharField(max_length=256)
 
 
 class PatientFacilityAddress(PatientAddress):
