@@ -1,6 +1,6 @@
 from django.db import models
 
-from canvas_sdk.v1.data.base import IdentifiableModel
+from canvas_sdk.v1.data.base import IdentifiableModel, TimestampedModel
 
 
 class PostingMethods(models.TextChoices):
@@ -12,7 +12,7 @@ class PostingMethods(models.TextChoices):
     OTHER = "other", "Other"
 
 
-class PaymentCollection(IdentifiableModel):
+class PaymentCollection(TimestampedModel, IdentifiableModel):
     """Stores the total collected amount and the payment method."""
 
     class Meta:
@@ -27,8 +27,5 @@ class PaymentCollection(IdentifiableModel):
 
     description = models.TextField()
 
-    created = models.DateTimeField(auto_now_add=True)
-    modified = models.DateTimeField(auto_now=True)
-
 
 __exports__ = ("PaymentCollection", "PostingMethods")
