@@ -2,9 +2,10 @@ from django.contrib.postgres.fields import ArrayField
 from django.db import models
 
 from canvas_sdk.v1.data.base import IdentifiableModel
+from canvas_sdk.v1.data.coding import Coding
 
 
-class ReasonForVisitSettingCoding(IdentifiableModel):
+class ReasonForVisitSettingCoding(IdentifiableModel, Coding):
     """ReasonForVisitSettingCoding."""
 
     class Meta:
@@ -12,11 +13,6 @@ class ReasonForVisitSettingCoding(IdentifiableModel):
 
     objects: models.Manager["ReasonForVisitSettingCoding"]
 
-    code = models.CharField(max_length=255)
-    display = models.CharField(max_length=1000)
-    system = models.CharField(max_length=255)
-    version = models.CharField(max_length=255)
-
     duration = ArrayField(models.DurationField())
 
 
