@@ -1,23 +1,19 @@
 import os
-from typing import cast
 
 import arrow
 from jwt import encode
 
 from logger import log
+from settings import PLUGIN_RUNNER_SIGNING_KEY
 
 ONE_DAY_IN_MINUTES = 60 * 24
 
-INSECURE_DEFAULT_SIGNING_KEY = "INSECURE_KEY"
-
 
 def token_for_plugin(
     plugin_name: str,
     audience: str,
     issuer: str = "plugin-runner",
-    jwt_signing_key: str = cast(
-        str, os.getenv("PLUGIN_RUNNER_SIGNING_KEY", INSECURE_DEFAULT_SIGNING_KEY)
-    ),
+    jwt_signing_key: str = PLUGIN_RUNNER_SIGNING_KEY,
     expiration_minutes: int = ONE_DAY_IN_MINUTES,
     extra_kwargs: dict | None = None,
 ) -> str:
@@ -27,9 +23,10 @@ def token_for_plugin(
     if not extra_kwargs:
         extra_kwargs = {}
 
-    if jwt_signing_key == INSECURE_DEFAULT_SIGNING_KEY:
+    if not jwt_signing_key:
         log.warning(
-            "Using an insecure JWT signing key for GraphQL access. Set the PLUGIN_RUNNER_SIGNING_KEY environment variable to avoid this message."
+            "Using an insecure JWT signing key for GraphQL access. Set the "
+            "PLUGIN_RUNNER_SIGNING_KEY environment variable to avoid this message."
         )
 
     token = encode(
